# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-08-20 18:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_configuration', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='configuration',
            name='type',
            field=models.CharField(choices=[('INTERNAL', 'INTERNAL'), ('EXTERNAL', 'EXTERNAL'), ('USER', 'USER')], default='EXTERNAL', max_length=10),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-01-07 18:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Configuration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('key', models.CharField(max_length=20)),
                ('value', models.TextField()),
            ],
            options={
                'verbose_name': 'configuration',
                'verbose_name_plural': 'configurations',
            },
        ),
    ]



from rest_framework import serializers

from plugs_configuration.models import Configuration

class ConfigurationSerializer(serializers.ModelSerializer):
    """
    Configuration Serializer
    """
    class Meta:
        """
        Metaclass definition
        """
        model = Configuration
        fields = ('key', 'value', 'type', 'user', 'created', 'updated')
        read_only_fields = ('type', 'user')



from django.db.models import Q

from rest_framework import viewsets

from plugs_core.permissions import IsOwnerOrReadOnly

from plugs_configuration.models import Configuration
from plugs_configuration import serializers

class ConfigurationViewSet(viewsets.ModelViewSet):
    """
    Configuration Viewset
    """
    queryset = Configuration.objects.exclude(type=Configuration.INTERNAL)
    serializer_class = serializers.ConfigurationSerializer
    permission_classes = [IsOwnerOrReadOnly]
    lookup_field = 'key'

    def perform_create(self, serializer):
        """
        Only user configurations can be created using the api
        """
        serializer.save(user=self.request.user, type=Configuration.USER)

    def get_queryset(self):
        if not self.request.user.is_authenticated():
            return self.queryset.exclude(type=Configuration.USER)
        else:
            return self.queryset.filter(Q(user=self.request.user) | Q(type=Configuration.EXTERNAL))



from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from plugs_core import mixins

class Configuration(mixins.Timestampable, models.Model):
    """
    Configuration model
    """
    INTERNAL = 'INTERNAL'
    EXTERNAL = 'EXTERNAL'
    USER = 'USER'

    TYPES = [
        (INTERNAL, _('INTERNAL')),
        (EXTERNAL, _('EXTERNAL')),
        (USER, _('USER')),
    ]

    key = models.CharField(max_length=20)
    value = models.TextField()
    type = models.CharField(max_length=10, choices=TYPES, default=EXTERNAL)
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True)

    # pylint: disable=R0903
    class Meta:
        """
        Providing verbose names is recommended if
        we want to use i18n in admin site
        """
        verbose_name = _('configuration')
        verbose_name_plural = _('configurations')



from django.contrib import admin

from plugs_configuration.models import Configuration

class ConfigurationAdmin(admin.ModelAdmin):
    """
    Configuration Model Admin
    """
    list_display = ('key', 'value', 'type', 'user')

admin.site.register(Configuration, ConfigurationAdmin)
